package go_handler_template

const ApiProductionPipeline = `
kind: pipeline
type: docker
name: 部署production-api-{{ .Name }}.{{ .NameSpace }}

steps:
  - name: build
    image: plugins/docker
    volumes:
      - name: docker
        path: /var/run/docker.sock
    settings:
      username: {{ .Reg.Username }}
      password: {{ .Reg.Password }}
      repo: {{ .Reg.Registry }}/{{ .NameSpace }}/api-{{ .Name }}
      registry: {{ .Reg.Registry }}
      tags:
        - ${DRONE_TAG}
        - latest
      dockerfile: ./{{ .Root }}/Dockerfile
      purge: false

  - name: deploy
    image: bitsbeats/drone-helm3
    settings:
      kube_api_server: {{ .Kube.KubeApiServer }}
      kube_token: {{ .Kube.KubeToken }}
      kube_certificate: {{ .Kube.KubeCertificate }}
      chart: ./{{ .Root }}/deploy
      release: api-{{ .Name }}
      wait: true
      namespace: {{ .NameSpace }}
      values:
        - nameSpace={{ .NameSpace }}
        - aliasName={{ .AliasName }}
        - image={{ .Reg.Registry }}/{{ .NameSpace }}/api-{{ .Name }}
        - imageTag=${DRONE_TAG}
        - port={{ .Port }}
{{ if .Host }}
        - host={{ .Host }}
{{ else }}
        - host=api.seamlesser.com
{{ end }}
{{ if .Path }}
        - path={{ .Path }}
{{ else }}
        - path=/{{ .NameSpace }}/{{ .Name }}/?(.*)
{{ end }}

volumes:
  - name: docker
    host:
      path: /var/run/docker.sock
`
